==> apache-fineract-1.8.4-src.tar.gz: apache-fineract-src-1.8.4/fineract-provider/src/main/java/org/apache/fineract/portfolio/loanaccount/domain/LoanTermVariationsComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.portfolio.loanaccount.domain;

import java.util.Comparator;

/**
 * Sort loan term variations
 */
public class LoanTermVariationsComparator implements Comparator<LoanTermVariations> {

    @Override
    public int compare(final LoanTermVariations o1, final LoanTermVariations o2) {
        int compareResult = 0;
        final int comparsion = o1.getTermApplicableFrom().compareTo(o2.getTermApplicableFrom());
        /**
         * For Terms bearing the same effective date, we sort based on modified date (when available) and new inserted
         * installment
         **/
        if (comparsion == 0) {
            if (o2.getTermType().isDueDateVariation() || o2.getTermType().isInsertInstallment()) {
                compareResult = 1;
            }
        } else {
            compareResult = comparsion;
        }

        return compareResult;
    }

}

==> apache-fineract-1.9.0-src.tar.gz: apache-fineract-src-1.9.0/fineract-provider/src/main/java/org/apache/fineract/portfolio/loanaccount/domain/LoanTermVariationsComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.portfolio.loanaccount.domain;

import java.util.Comparator;

/**
 * Sort loan term variations
 */
public class LoanTermVariationsComparator implements Comparator<LoanTermVariations> {

    @Override
    public int compare(final LoanTermVariations o1, final LoanTermVariations o2) {
        int compareResult = 0;
        final int comparsion = o1.getTermApplicableFrom().compareTo(o2.getTermApplicableFrom());
        // For Terms bearing the same effective date, we sort based on modified date (when available) and new inserted
        // installment
        if (comparsion == 0) {
            if (o2.getTermType().isDueDateVariation() || o2.getTermType().isInsertInstallment()) {
                compareResult = 1;
            }
        } else {
            compareResult = comparsion;
        }

        return compareResult;
    }

}
